@@ -156,9 +156,8 @@ class VasprunData(Dict2Data):
     def __repr__(self):
         return super().__repr__().replace("Data","VasprunData",1)
     
-    @property
-    def fermi(self):
-        "Fermi energy based on occupancy. Returns `self.Fermi` if occupancies cannot be resolved."
+    def get_fermi(self,tol=1e-3):
+        "Fermi energy based on occupancy. Returns `self.Fermi` if occupancies cannot be resolved. `tol` is the value of occupnacy to ignore as filled."
         try:
             if self.sys_info.ISPIN == 1:
                 return float(self.bands.evals[self.bands.occs > 0].max())
@@ -171,6 +170,11 @@ class VasprunData(Dict2Data):
         except:
             return self.Fermi
     
+    @property
+    def fermi(self):
+        "Fermi energy based on occupancy. Use .get_fermi() if you want to limit the occupancy tolerance."
+        return self.get_fermi(tol=1e-3)
+    
     @property
     def Fermi(self):
         "Fermi energy given in vasprun.xml."
@@ -186,21 +190,25 @@ class SpinData(Dict2Data):
     def __repr__(self):
         return super().__repr__().replace("Data","SpinData",1)
     
-    @property
-    def fermi(self):
-        "Fermi energy based on occupancy. Returns `self.Fermi` if occupancies cannot be resolved."
+    def get_fermi(self, tol = 1e-3):
+        "Fermi energy based on occupancy. Returns `self.Fermi` if occupancies cannot be resolved. `tol` is the value of occupnacy to ignore as filled."
         try:
             if self.sys_info.ISPIN == 1:
-                return float(self.evals.e[self.evals.occs > 0].max())
+                return float(self.evals.e[self.evals.occs > tol].max())
                 
             else: # ISPIN 2
                 energies = []
                 for a, b in [('u','SpinUp'),('d','SpinDown')]:
-                    energies.append(self.evals[a][self.evals.occs[b] > 0].max())
+                    energies.append(self.evals[a][self.evals.occs[b] > tol].max())
                 return float(max(energies))
         except:
             return self.Fermi
     
+    @property
+    def fermi(self):
+        "Fermi energy based on occupancy. Use .get_fermi() if you want to limit the occupancy tolerance."
+        return self.get_fermi(tol = 1e-3)
+    
     @property
     def Fermi(self):
         "Fermi energy given in vasprun.xml."
@@ -228,13 +236,13 @@ class PoscarData(Dict2Data):
         return write_poscar(self,sd_list = sd_list,outfile = outfile,overwrite = overwrite)
         
 
-class LocpotData(Dict2Data):
-    _req_keys = ('ElemName','ElemIndex','SYSTEM')
+class GridData(Dict2Data):
+    _req_keys = ('path','poscar','SYSTEM')
     def __init__(self,d):
         super().__init__(d)
     
     def __repr__(self):
-        return super().__repr__().replace("Data","LocpotData",1)
+        return super().__repr__().replace("Data","GridData",1)
 
 class OutcarData(Dict2Data):
     _req_keys = ('site_pot','ion_pot','basis')
